/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.harness;

import javax.swing.JFrame;
import javax.swing.JOptionPane;

/**
 * Various dialog boxes.
 * 
 * @author Pavel Tisnovsky
 */
public class Dialogs
{
    private static final String ABOUT_TEXT = "Gfx test harness version 0.1\nAuthor: Pavel Tisnovsky, Red Hat";

    private final String title;
    private final JFrame window;

    public Dialogs(String title, JFrame window)
    {
        this.title = title;
        this.window = window;
    }

    public void showInfoMessage(String message)
    {
        JOptionPane.showMessageDialog(this.window, message, this.title, JOptionPane.INFORMATION_MESSAGE);
    }

    public void showErrorMessage(String message)
    {
        JOptionPane.showMessageDialog(this.window, message, this.title, JOptionPane.ERROR_MESSAGE);
    }

    public void showWarningMessage(String message)
    {
        JOptionPane.showMessageDialog(this.window, message, this.title, JOptionPane.WARNING_MESSAGE);
    }

    public void showNoTestSelectedMessage()
    {
        this.showErrorMessage("No test selected in left list box!");
    }

    public void showDialogWhenCompilationFailed(Exception e)
    {
        this.showErrorMessage("Error occured during compilation: " + e.getMessage());
    }

    public void showDialogWhenRunTestFailed(Exception e)
    {
        this.showErrorMessage("Error occured during test run: " + e.getMessage());
    }

    public void showAboutDialog()
    {
        this.showInfoMessage(ABOUT_TEXT);
    }

    public void showDialogAfterLoadConfiguration(boolean result)
    {
        if (result)
        {
            this.showInfoMessage("Configuration successfully loaded");
        }
        else
        {
            this.showErrorMessage("Error occured during configuration loading!");
        }
    }

    public void showDialogAfterSaveConfiguration(boolean result)
    {
        if (result)
        {
            this.showInfoMessage("Configuration successfully saved");
        }
        else
        {
            this.showErrorMessage("Error occured during configuration saving!");
        }
    }
}
